OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "﻿ಕೆಳಗಿನ ಬಳಕೆದಾರರಿಗೆ ಈ-ಮೇಲ್ ಕಳುಹಿಸಿ ಸಾಧ್ಯವಾಗುತ್ತಿಲ್ಲ: %s",
    "Turned on maintenance mode" : "ನಿರ್ವಹಣೆಯ ಸ್ತಿತಿಯನ್ನು ಆರಂಭಿಸಲಾಗಿದೆ",
    "Turned off maintenance mode" : "ನಿರ್ವಹಣೆಯ ಸ್ತಿತಿಯನ್ನು ಮುಕ್ತಗೊಳಿಸಲಾಗಿದೆ",
    "Updated database" : "ದತ್ತಸಂಚಯ ",
    "Checked database schema update" : "﻿ಪರಿಶೀಲಿಸಿದ ದತ್ತಸಂಚಯ ಯೋಜನಾ ಅಪ್ಡೇಟ್",
    "Checked database schema update for apps" : "ನವೀಕರಿಸಿದ ದತ್ತಸಂಚಯದ ಯೋಜನಾ ಪ್ರತಿಗಳನ್ನು ಕಾಯಕ್ರಮಗಳೊಂದಿಗೆ ಪರಿಶೀಲಿಸಲಾಗಿದೆ",
    "Updated \"%s\" to %s" : "﻿%s ರ ಆವೃತ್ತಿ %s ನ್ನು ನವೀಕರಿಸಲಾಗುತ್ತದೆ.",
    "No image or file provided" : "ಚಿತ್ರ ಅಥವಾ ಕಡತದ ಕೊರತೆ ಇದೆ",
    "Unknown filetype" : "﻿ಅಪರಿಚಿತ ಕಡತ ಮಾದರಿ",
    "Invalid image" : "ಅಸಾಮರ್ಥ್ಯ ಚಿತ್ರ",
    "No temporary profile picture available, try again" : "﻿ಯಾವುದೇ ತಾತ್ಕಾಲಿಕ ವ್ಯಕ್ತಿ ಚಿತ್ರ ದೊರಕುತ್ತಿಲ್ಲ, ಮತ್ತೆ ಪ್ರಯತ್ನಿಸಿ",
    "No crop data provided" : "﻿ಸುಕ್ಕು  ಒದಗಿಸಿದ ಮಾಹಿತಿ ",
    "Sunday" : "﻿ಭಾನುವಾರ",
    "Monday" : "﻿ಸೋಮವಾರ",
    "Tuesday" : "﻿ಮಂಗಳವಾರ",
    "Wednesday" : "﻿ಬುಧವಾರ",
    "Thursday" : "﻿ಗುರುವಾರ",
    "Friday" : "﻿ಶುಕ್ರವಾರ",
    "Saturday" : "﻿ಶನಿವಾರ",
    "January" : "﻿ಜನವರಿ",
    "February" : "﻿ಫೆಬ್ರುವರಿ",
    "March" : "﻿ಮಾರ್ಚ್",
    "April" : "﻿ಏಪ್ರಿಲ್",
    "May" : "﻿ಮೇ",
    "June" : "﻿ಜೂನ್",
    "July" : "﻿ಜುಲೈ",
    "August" : "﻿ಆಗಸ್ಟ್",
    "September" : "﻿ಸೆಪ್ಟೆಂಬರ್",
    "October" : "﻿ಅಕ್ಟೋಬರ್",
    "November" : "﻿ನವೆಂಬರ್",
    "December" : "﻿ಡಿಸೆಂಬರ್",
    "Settings" : "ಆಯ್ಕೆಗಳು",
    "Saving..." : "﻿ಉಳಿಸಲಾಗುತ್ತಿದೆ ...",
    "Couldn't send reset email. Please contact your administrator." : "﻿ರೀಸೆಟ್ ಇಮೇಲ್ ಕಳುಹಿಸಲು ಸಾಧ್ಯವಾಗಲಿಲ್ಲ. ನಿಮ್ಮ ನಿರ್ವಾಹಕರನ್ನು ಸಂಪರ್ಕಿಸಿ.",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "﻿ನಿಮ್ಮ ಗುಪ್ತಪದ ಮರುಹೊಂದಿಸಲು  ಅಂತ್ರಜಾಲ ಕೊಂಡಿಯನ್ನು ನಿಮ್ಮ ಇ-ಅಂಚೆ ಪೆಟ್ಟಿಗೆಗೆ ಕಳುಹಿಸಲಾಗಿದೆ. ಇದನ್ನು ನಿರ್ದಿಷ್ಟ ಸಮಯದಲ್ಲಿ ಇ-ಅಂಚೆ ಪೆಟ್ಟಿಗೆಯ ಮುಖ್ಯ ಕೂಶದಲ್ಲಿ ಪಡೆಯದಿದ್ದಲ್ಲಿ, ಇತರೇ ಕೂಶಗಳನ್ನು ಪರಿಶೀಲಿಸಿ. <br> ಇದು ಇನ್ನು  ಬಾರದೆ ಇದ್ದರೆ, ನಿಮ್ಮ ಸ್ಥಳೀಯ ಸಂಕೀರ್ಣ ವ್ಯವಸ್ಥೆಯ ನಿರ್ವಾಹಕರ ಸಹಾಯ ಕೇಳಿ.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "﻿ನಿಮ್ಮ ಕಡತಗಳನ್ನು ಎನ್ಕ್ರಿಪ್ಟ್. ನೀವು ಚೇತರಿಕೆ ಕೀ ಸಶಕ್ತ ಇದ್ದರೆ, ನಿಮ್ಮ ಪಾಸ್ವರ್ಡ್ ರೀಸೆಟ್ ಮತ್ತೆ ನಂತರ ನಿಮ್ಮ ಡೇಟಾವನ್ನು ಪಡೆಯಲು ಯಾವುದೇ ದಾರಿ ಇರುತ್ತದೆ. <br /> ನೀವು ಏನು ಖಚಿತವಾಗಿ ಇದ್ದರೆ ನೀವು ಮುಂದುವರೆಯಲು ಮೊದಲು, ನಿಮ್ಮ ನಿರ್ವಾಹಕರನ್ನು ಸಂಪರ್ಕಿಸಿ. <br /> ನೀವು ನಿಜವಾಗಿಯೂ ಮುಂದುವರಿಸಲು ಬಯಸುತ್ತೀರಾ?",
    "I know what I'm doing" : "ಏನು ಮಾಡುತ್ತಿರುವೆ ಎಂದು ನನಗೆ ತಿಳಿದಿದೆ",
    "Password can not be changed. Please contact your administrator." : "ಗುಪ್ತಪದ ಬದಲಾವಣೆ ಸಾಧ್ಯವಿಲ್ಲ. ನಿಮ್ಮ ನಿರ್ವಾಹಕರನ್ನು ಸಂಪರ್ಕಿಸಿ.",
    "No" : "﻿ಇಲ್ಲ",
    "Yes" : "﻿ಹೌದು",
    "Choose" : "﻿ಆಯ್ಕೆ",
    "Ok" : "﻿ಸರಿ",
    "read-only" : "﻿ಓದಲು ಮಾತ್ರ",
    "One file conflict" : "﻿ಒಂದು ಕಡತದಲ್ಲಿ ಸಮಸ್ಯೆ ಇದೆ",
    "New Files" : "ಹೊಸ ಕಡತಗಳು",
    "Already existing files" : "﻿ಈಗಾಗಲೇ ಅಸ್ತಿತ್ವದಲ್ಲಿರುವ ಕಡತಗಳು",
    "Which files do you want to keep?" : "﻿ಯಾವ ಕಡತಗಳನ್ನು ಇರಿಸಿಕೊಳ್ಳಲು ಬಯಸುತ್ತೀರಿ?",
    "If you select both versions, the copied file will have a number added to its name." : "ನೀವು ಎರಡೂ ಆವೃತ್ತಿಗಳನ್ನು ಆರಿಸಿದರೆ, ನಕಲು ಕಡತ ಸಂಖ್ಯೆಯನ್ನು ಅದರ ಹೆಸರನ್ನು ಸೇರಿಸಲಾಗಿದೆ ಹೊಂದಿರುತ್ತದೆ.",
    "Cancel" : "﻿ರದ್ದು",
    "Continue" : "﻿ಮುಂದುವರಿಸಿ",
    "(all selected)" : "﻿(ಎಲ್ಲಾ ಆಯ್ಕೆ)",
    "({count} selected)" : "({count} ಆಯ್ಕೆಗಳು)",
    "Very weak password" : "ಅತೀ ದುರ್ಬಲ ಗುಪ್ತಪದ",
    "Weak password" : "ದುರ್ಬಲ ಗುಪ್ತಪದ",
    "So-so password" : "ಊಹಿಸಬಹುದಾದ ಗುಪ್ತಪದ",
    "Good password" : "ಉತ್ತಮ ಗುಪ್ತಪದ",
    "Strong password" : "﻿ಪ್ರಬಲ ಗುಪ್ತಪದ",
    "Error occurred while checking server setup" : "ಪರಿಚಾರಿಕ ಗಣಕವನ್ನು ಪರಿಶೀಲಿಸುವಾಗ ದೋಷವುಂಟಾಗಿದೆ",
    "Shared" : "﻿ಹಂಚಿಕೆಯ",
    "Shared with {recipients}" : "ಹಂಚಿಕೆಯನ್ನು ಪಡೆದವರು {recipients}",
    "Share" : "﻿ಹಂಚಿಕೊಳ್ಳಿ",
    "Error" : "﻿ತಪ್ಪಾಗಿದೆ",
    "Error while sharing" : "ಹಂಚುವಾಗ ಏನೊ ಲೋಪವಾಗಿದೆ",
    "Error while unsharing" : " ಹಂಚಿಕೆಯನ್ನು ಹಿಂದೆರುಗಿಸು ಸಂದರ್ಭದಲ್ಲಿ ಲೋಪವಾಗಿದೆ",
    "Error while changing permissions" : "ಅನುಮತಿಗಳನ್ನು ಬದಲಾವಣೆ ಮಾಡುವಾಗ ದೋಷವಾಗಿದೆ",
    "Shared with you and the group {group} by {owner}" : "ನಿಮಗೆ ಮತ್ತು {group} ಗುಂಪಿನೂಂದಿಗೆ {owner} ಹಂಚಿಕೊಂಡಿದ್ದಾರೆ",
    "Shared with you by {owner}" : "﻿ನಿಮ್ಮೊಂದಿಗೆ {owner} ಹಂಚಿಕೊಂಡಿದ್ದಾರೆ",
    "Share link" : "ಸಂಪರ್ಕ ಕೊಂಡಿಯನ್ನು  ﻿ಹಂಚಿಕೊಳ್ಳಬಹುದು",
    "The public link will expire no later than {days} days after it is created" : "﻿ರಚನೆಯಾದ {days} ದಿನಗಳ ನಂತರ ಈ ಸಾರ್ವಜನಿಕ ಸಂಪರ್ಕ ಕೊಂಡಿ ಅಂತ್ಯಗೊಳ್ಳಲಿದೆ",
    "Link" : "ಸಂಪರ್ಕ ಕೊಂಡಿ",
    "Password protect" : "﻿ಗುಪ್ತಪದ ರಕ್ಷಿಸಿಕೂಳ್ಲಿ",
    "Password" : "ಗುಪ್ತಪದ",
    "Choose a password for the public link" : "ಸಾರ್ವಜನಿಕ ಸಂಪರ್ಕ ಕೊಂಡಿಗೆ ಗುಪ್ತಪದ ಆಯ್ಕೆಮಾಡಿ",
    "Allow editing" : "﻿ಸಂಪಾದನೆಗೆ ಅವಕಾಶ ಮಾಡಿಕೊಡಿ",
    "Email link to person" : "ಬಳಕೆದಾರನ ಇ-ಅಂಚೆಯ ಸಂಪರ್ಕಕೊಂಡಿ",
    "Send" : "﻿ಕಳುಹಿಸಿ",
    "Set expiration date" : "ಮುಕ್ತಾಯ ದಿನಾಂಕವನ್ನು ನಿರ್ದರಿಸಿ",
    "Expiration" : "﻿ಮುಕ್ತಾಯ",
    "Expiration date" : "ಮುಕ್ತಾಯ ದಿನಾಂಕ",
    "Adding user..." : "﻿ಬಳಕೆದಾರನನ್ನು ಸೇರಿಸಲಾಗುತ್ತಿದೆ ...",
    "group" : "﻿ಗುಂಪು",
    "remote" : "ಆಚೆಯ",
    "Resharing is not allowed" : "﻿ಮರುಹಂಚಿಕೆ ಅನುಮತಿಸಲಾಗುವುದಿಲ್ಲ",
    "Shared in {item} with {user}" : "{user} ﻿ಜೊತೆ {item} ಹಂಚಿಕೊಳ್ಳಲಾಗಿದೆ",
    "Unshare" : "ಹಂಚಿಕೆಯನ್ನು ಹಿಂತೆಗೆ",
    "notify by email" : "﻿ಇ-ಅಂಚೆ ಮೂಲಕ ತಿಳಿಸಲು",
    "can share" : "﻿ಹಂಚಿಕೊಳ್ಳಬಹುದು",
    "can edit" : "﻿ಸಂಪಾದಿಸಬಹುದು",
    "access control" : "﻿ಪ್ರವೇಶ ನಿಯಂತ್ರಣ",
    "create" : "ಸೃಷ್ಟಿಸು",
    "change" : "﻿ಬದಲಾವಣೆ",
    "delete" : "﻿ಅಳಿಸಿ",
    "Password protected" : "ಗುಪ್ತಪದದಿಂದ ರಕ್ಷಿಸಲಾಗಿದೆ",
    "Error unsetting expiration date" : "ಮುಕ್ತಾಯ ದಿನಾಂಕವನ್ನು ಹಿಂಪಡೆಯುವಲಿ್ಲ ದೋಷ",
    "Error setting expiration date" : "ಮುಕ್ತಾಯ ದಿನಾಂಕವನ್ನು ನಿರ್ದರಿಸುವಲ್ಲಿ ದೋಷ",
    "Sending ..." : "﻿ಕಳುಹಿಸಲಾಗುತ್ತಿದೆ ...",
    "Email sent" : "ಇ-ಅಂಚೆ ಕಳುಹಿಸಲಾಗಿದೆ",
    "Warning" : "﻿ಎಚ್ಚರಿಕೆ",
    "The object type is not specified." : "﻿ವಸ್ತು ಮಾದರಿ ನಿರ್ದಿಷ್ಟಪಡಿಸಲಾಗಿಲ್ಲ.",
    "Enter new" : "﻿ಹೊಸ ನಮೂದನೆ",
    "Delete" : "﻿ಅಳಿಸಿ",
    "Add" : "﻿ಸೇರಿಸಿ",
    "Edit tags" : "ಕಿರು-ಪದ ಗಳನ್ನು ﻿ಸಂಪಾದಿಸು",
    "No tags selected for deletion." : "ಯಾವುದೇ ಕಿರು ಪದಗಳನ್ನ  ಅಳಿಸಲು ﻿ಆಯ್ಕೆ ಇಲ್ಲ.",
    "unknown text" : "ತಿಳಿಯದ ವಿಷಯ",
    "Hello world!" : "ಹೇ ಲೋಕವೇ ನಿನಗೆ ನಮಸ್ಕಾರ!",
    "sunny" : "ಬಿಸಿಲಿನ",
    "Hello {name}, the weather is {weather}" : "ನಮಸ್ಕಾರ {name}, ಸದ್ಯ {weather} ಹವಾಮಾನವಿದೆ",
    "_download %n file_::_download %n files_" : ["%n ಕಡತಗಳನ್ನು ಸ್ಥಳೀಯ ಪ್ರತಿಯಾಗಿಸಿ"],
    "Please reload the page." : "﻿ಪುಟವನ್ನು ಪುನಃ ನವೀಕರಿಸಿ.",
    "The update was unsuccessful. " : "ಆಧುನೀಕರಿಣೆ ಯಶಸ್ವಿಯಾಗಿಲ್ಲ.",
    "Couldn't reset password because the token is invalid" : "﻿ಚಿಹ್ನೆ ಅಮಾನ್ಯವಾಗಿದೆ, ಗುಪ್ತಪದ ಮರುಹೊಂದಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ",
    "Couldn't send reset email. Please make sure your username is correct." : "ಬದಲಾವಣೆಯ ಇ-ಅಂಚೆಯನ್ನು ಕಳುಹಿಸಲು ಸಾಧ್ಯವಾಗಲಿಲ್ಲ. ನಿಮ್ಮ ಬಳಕೆದಾರ ಹೆಸರು ಸರಿಯಾಗಿದೆ ಖಚಿತಪಡಿಸಿಕೊಳ್ಳಿ.",
    "Couldn't send reset email because there is no email address for this username. Please contact your administrator." : "﻿ಈ ಬಳಕೆದಾರನ ಹೆಸರಿನ್ನಲ್ಲಿ ಯಾವುದೇ ಇ-ಅಂಚೆ ವಿಳಾಸ ಇಲ್ಲದರಿರುವುದರಿಂದ ಬದಲಾವಣೆಯ ಇ-ಅಂಚೆಯನ್ನು  ಕಳುಹಿಸಲು ಸಾಧ್ಯವಾಗುತ್ತಿಲ್ಲ. ನಿಮ್ಮ ನಿರ್ವಾಹಕರನ್ನು ಸಂಪರ್ಕಿಸಿ.",
    "%s password reset" : "%s ಗುಪ್ತ ಪದವನ್ನು ಮರುಹೊಂದಿಸಿ",
    "Use the following link to reset your password: {link}" : "ನಿಮ್ಮ ಗುಪ್ತಪದ ಮರುಹೊಂದಿಸಲು ಕೆಳಗಿನ ಅಂತ್ರಜಾಲ ಕೊಂಡಿಯನ್ನು ಬಳಸಿ : {link}",
    "New password" : "﻿ಹೊಸ ಗುಪ್ತಪದ",
    "New Password" : "ಹೊಸ ಗುಪ್ತಪದ",
    "Reset password" : "ಗುಪ್ತ ಪದವನ್ನು ಮರುಹೊಂದಿಸಿ",
    "Personal" : "﻿ವೈಯಕ್ತಿಕ",
    "Users" : "﻿ಬಳಕೆದಾರರು",
    "Apps" : "ಕಾರ್ಯಕ್ರಮಗಳು",
    "Admin" : "﻿ನಿರ್ವಹಕ",
    "Help" : "﻿ಸಹಾಯ",
    "Error loading tags" : "﻿ಕಿರು ಪದಗಳನ್ನ ಪಡೆಯುವಲ್ಲಿ ಲೋಪವಾಗಿದೆ",
    "Tag already exists" : "ಕಿರು ಪದ ಈಗಾಗಲೇ ಅಸ್ತಿತ್ವದಲ್ಲಿದೆ",
    "Error deleting tag(s)" : "﻿ಕಿರು-ಪದ(ಗಳನ್ನು) ಅಳಿಸುವಲ್ಲಿ ಲೋಪವಾದೆ",
    "Error tagging" : "ಕಿರು-ಪದ ಅಸ್ತಿತ್ವಗೂಳಿಸಲಯ ",
    "Error untagging" : "ಕಿರು-ಪದವನ್ನು ತೆರುವುಗೂಳಿಸುವಲಿ್ಲ ದೋಷ",
    "Error favoriting" : "ಒಲವು ತೋರಿಸುವಲ್ಲಿ ದೋಷ",
    "Error unfavoriting" : "ಒಲವು ಬದಲಾಯಿಸುವಲ್ಲಿ ದೋಷ",
    "Access forbidden" : "﻿ಪ್ರವೇಶ ನಿರ್ಬಂಧಿಸಲಾಗಿದೆ",
    "File not found" : "ಕಡತ ಕಂಡುಬಂದಿಲ್ಲ",
    "You can click here to return to %s." : "ಮರಳಿ ಹೋಗುಲು ಇಲ್ಲಿ ಆಯ್ಕೆ ಮಾಡಿ %s",
    "Cheers!" : "ಆನಂದಿಸಿ !",
    "Internal Server Error" : "ಪರಿಚಾರಕ-ಗಣಕದ ಆಂತರಿಕ ದೋಷ",
    "Technical details" : "ತಾಂತ್ರಿಕ ವಿವರಗಳು",
    "Remote Address: %s" : "ಆಚೆ-ಗಣಕದ ವಿಳಾಸ : %s",
    "Request ID: %s" : "ವಿನಂತಿಯ ಸಂಖ್ಯೆ: %s",
    "Code: %s" : "ಸ೦ಕೇತ: %s",
    "Message: %s" : "ಸ೦ದೇಶ: %s",
    "File: %s" : "ಕಡತ: %s",
    "Line: %s" : "ಕೋಂಡಿ: %s",
    "Trace" : "ಕುರುಹು",
    "Username" : "﻿ಬಳಕೆಯ ಹೆಸರು",
    "Storage & database" : "ಶೇಖರಣಾ ಮತ್ತು ದತ್ತಸಂಚಯ",
    "Data folder" : "﻿ಮಾಹಿತಿ ಕೋಶ",
    "Configure the database" : "ದತ್ತಸಂಚಯದ ಆಯ್ಕೆಗಳು",
    "Only %s is available." : "ಕೇವಲ ﻿%s ಮಾತ್ರ ಲಭ್ಯವಿದೆ.",
    "Database user" : "﻿ ದತ್ತಸಂಚಯದ ಬಳಕೆದಾರ",
    "Database password" : " ದತ್ತಸಂಚಯದ ಗುಪ್ತಪದ",
    "Database name" : "ದತ್ತಸಂಚಯದ ಹೆಸರು",
    "Database tablespace" : "ದತ್ತಸಂಚಯದ tablespace",
    "Database host" : "ದತ್ತಸಂಚಯದ ಅತಿಥೆಯ",
    "Finish setup" : "ಹೊಂದಾಣಿಕೆಗಳನ್ನು ಪೂರ್ಣಗೊಳಿಸಿ",
    "Finishing …" : "ಪೂರ್ಣಗೊಳಿಸಲಾಗುತ್ತಿದೆ ...",
    "Log out" : "ಈ ಆವೃತ್ತಿ ಇಂದ ನಿರ್ಗಮಿಸಿ",
    "Search" : "﻿ಹುಡುಕು",
    "Please contact your administrator." : "ನಿಮ್ಮ ನಿರ್ವಾಹಕರನ್ನು ಸಂಪರ್ಕಿಸಲು ಕೋರಲಾಗಿದೆ.",
    "Forgot your password? Reset it!" : "ನಿಮ್ಮ ಗುಪ್ತಪದವನ್ನು ಮರೆತಿರಾ? ಮರುಹೊಂದಿಸಿ!",
    "remember" : "﻿ನೆನಪಿಡಿ",
    "This ownCloud instance is currently in single user mode." : "ಪ್ರಸ್ತುತ ಕ್ರಮದಲ್ಲಿ, ಈ OwnCloud ನ್ನು ಕೇವಲ ಒಬ್ಬನೇ ಬಳಕೆದಾರ ಮಾತ್ರ ಬಳಸಬಹುದಾಗಿದೆ.",
    "This means only administrators can use the instance." : "ಇದರ ಅರ್ಥ, ಸದ್ಯದ ನಿದರ್ಶನದಲ್ಲಿ ನಿರ್ವಾಹಕರು ಮಾತ್ರ ಬಳಸಬಹುದಾಗಿದೆ.",
    "Thank you for your patience." : "﻿ನಿಮ್ಮ ತಾಳ್ಮೆಗೆ ಧನ್ಯವಾದಗಳು.",
    "%s will be updated to version %s." : "﻿%s ರ ಆವೃತ್ತಿ %s ನ್ನು ನವೀಕರಿಸಲಾಗುತ್ತದೆ.",
    "The following apps will be disabled:" : "﻿ಈ ಕೆಳಗಿನ ಕಾರ್ಯಕ್ರಮಗಳನ್ನು ನಿಷ್ಕ್ರಿಯಗೊಳಿಸಲಾಗುತ್ತದೆ:",
    "Start update" : "ನವೀಕರಿಣವನ್ನು ಆರಂಭಿಸಿ"
},
"nplurals=1; plural=0;");
